OSM Viz Examples

## Examples

#### Multiple Icons Moving on a Map This example shows the creation and animation of several TrackingViz objects. View code |
#### Custom Animation This example demonstrates the creation of a custom SimViz subclass in order to do a more customized animation. View code |
#### PIL Images This example shows how to create and show a PIL image of several OSM tiles patched together. View code |